pub struct TestRunnerConfig<FEN: FoundryEvmNetwork> {
pub config: Arc<Config>,
pub inline_config: Arc<InlineConfig>,
pub evm_opts: EvmOpts,
pub evm_env: EvmEnvFor<FEN>,
pub tx_env: TxEnvFor<FEN>,
pub spec_id: SpecFor<FEN>,
pub sender: Address,
pub line_coverage: bool,
pub debug: bool,
pub decode_internal: InternalTraceMode,
pub isolation: bool,
pub early_exit: EarlyExit,
}Expand description
Configuration for the test runner.
This is modified after instantiation through inline config.
Fields
config: Arc<Config>Project config.
inline_config: Arc<InlineConfig>Inline configuration.
evm_opts: EvmOptsEVM configuration.
evm_env: EvmEnvFor<FEN>EVM environment.
tx_env: TxEnvFor<FEN>Transaction environment.
spec_id: SpecFor<FEN>EVM version.
sender: AddressThe address which will be used to deploy the initial contracts and send all transactions.
line_coverage: boolWhether to collect line coverage info
debug: boolWhether to collect debug info
decode_internal: InternalTraceModeWhether to enable steps tracking in the tracer.
isolation: boolWhether to enable call isolation.
early_exit: EarlyExitWhether to exit early on test failure or if test run interrupted.
Implementations
Sourceimpl<FEN: FoundryEvmNetwork> TestRunnerConfig<FEN>
impl<FEN: FoundryEvmNetwork> TestRunnerConfig<FEN>
Sourcepub fn reconfigure_with(&mut self, config: Arc<Config>)
pub fn reconfigure_with(&mut self, config: Arc<Config>)
Reconfigures all fields using the given config.
This is for example used to override the configuration with inline config.
Sourcepub fn configure_executor(&self, executor: &mut Executor<FEN>)
pub fn configure_executor(&self, executor: &mut Executor<FEN>)
Configures the given executor with this configuration.
Sourcepub fn executor(
&self,
known_contracts: ContractsByArtifact,
analysis: Arc<Compiler>,
artifact_id: &ArtifactId,
db: Backend<FEN>,
) -> Executor<FEN>
pub fn executor( &self, known_contracts: ContractsByArtifact, analysis: Arc<Compiler>, artifact_id: &ArtifactId, db: Backend<FEN>, ) -> Executor<FEN>
Creates a new executor with this configuration.
fn trace_mode(&self) -> TraceMode